==> glib-web-0.11.8.tgz: package/components/mixins/generic.js <==
export default {
  methods: {
    $closest(name) {
      var parent = this.$parent;
      while (parent != null) {
        if (
          Utils.type.isObject(parent.spec) &&
          Utils.app.vueName(parent) == name
        ) {
          return parent;
        }
        parent = parent.$parent;
      }
    },
    $validation(rules) {
      var augmentedRules = rules || [];
      Utils.type.ifObject(this.spec.validation, val => {
        Utils.type.ifObject(val.required, spec => {
          augmentedRules = augmentedRules.concat([
            v => (v ? true : spec.message)
          ]);
        });
      });
      return augmentedRules;
    },
    // // This can be overridden by the component to ensure that dialogs are shown within the component,
    // // which is necessary for operations requiring certain hierarchy, e.g. submitting a form from a
    // // child dialog.
    // $dialogContainer() {
    //   return document.body;
    // },
    $wsSubscribeEvents(spec) {
      if (!Utils.type.isObject(spec)) {
        return;
      }

      const topicName = spec.topic;
      const events = spec.events;
      if (!Utils.type.isString(topicName) || !Utils.type.isArray(events)) {
        return;
      }

      const ws = window.vueApp.webSocket;
      const channel = ws.channels[topicName];

      if (!channel) {
        console.log(`Topic not ready: '${topicName}'`);
        setTimeout(() => {
          // Wait until $wsInitPhoenixSocket() has executed.
          this.$wsSubscribeEvents(spec);
        }, 200);
        return;
      }

      for (const eventName of events) {
        console.log(`Registering event '${eventName}'`);
        channel.on(eventName, payload => {
          console.debug(`Received '${eventName}' event`, payload);
          Utils.ws.handleResponse(payload.onResponse, this);
        });
      }
    }
  }
};

==> glib-web-2.6.3.tgz: package/components/mixins/generic.js <==
export default {
  methods: {
    $closest(name) {
      var parent = this.$parent;
      while (parent != null) {
        if (
          Utils.type.isObject(parent.spec) &&
          GLib.component.vueName(parent) == name
        ) {
          return parent;
        }
        parent = parent.$parent;
      }
    },
    $validation(rules) {
      var augmentedRules = rules || [];
      Utils.type.ifObject(this.spec.validation, val => {
        Utils.type.ifObject(val.required, spec => {
          augmentedRules = augmentedRules.concat([
            v => (v ? true : spec.message)
          ]);
        });
        Utils.type.ifObject(val.format, spec => {
          augmentedRules = augmentedRules.concat([
            v => {
              if (v && !v.match(spec.regex)) {
                return spec.message;
              }
              return true;
            }
          ]);
        });
      });
      return augmentedRules;
    },
    // // This can be overridden by the component to ensure that dialogs are shown within the component,
    // // which is necessary for operations requiring certain hierarchy, e.g. submitting a form from a
    // // child dialog.
    // $dialogContainer() {
    //   return document.body;
    // },
    $wsSubscribeEvents(spec) {
      if (!Utils.type.isObject(spec)) {
        return;
      }

      const topicName = spec.topic;
      const events = spec.events;
      if (!Utils.type.isString(topicName) || !Utils.type.isArray(events)) {
        return;
      }

      const ws = window.vueApp.webSocket;
      const channel = ws.channels[topicName];

      if (!channel) {
        console.log(`Topic not ready: '${topicName}'`);
        setTimeout(() => {
          // Wait until $wsInitPhoenixSocket() has executed.
          this.$wsSubscribeEvents(spec);
        }, 200);
        return;
      }

      for (const eventName of events) {
        console.log(`Registering event '${eventName}'`);
        channel.on(eventName, payload => {
          console.debug(`Received '${eventName}' event`, payload);
          Utils.ws.handleResponse(payload.onResponse, this);
        });
      }
    }
  }
};
